@@ -14,8 +14,6 @@
 
 import abc
 
-import six
-
 from keystone.common import provider_api
 import keystone.conf
 from keystone import exception
@@ -24,8 +22,8 @@ from keystone import exception
 CONF = keystone.conf.CONF
 
 
-@six.add_metaclass(abc.ABCMeta)
-class CatalogDriverBase(provider_api.ProviderAPIMixin, object):
+class CatalogDriverBase(provider_api.ProviderAPIMixin, object,
+                        metaclass=abc.ABCMeta):
     """Interface description for the Catalog driver."""
 
     def _get_list_limit(self):
@@ -441,7 +439,7 @@ class CatalogDriverBase(provider_api.ProviderAPIMixin, object):
         raise exception.NotImplemented()  # pragma: no cover
 
     @abc.abstractmethod
-    def list_endpoint_groups(self):
+    def list_endpoint_groups(self, hints):
         """List all endpoint groups.
 
         :returns: None.
