@@ -17,6 +17,9 @@
 import os
 import sys
 
+from keystone.cmd import cli
+
+
 # If ../../keystone/__init__.py exists, add ../../ to Python search path, so
 # that it will override what happens to be installed in
 # /usr/(local/)lib/python...
@@ -29,16 +32,10 @@ if os.path.exists(os.path.join(possible_topdir,
                                '__init__.py')):
     sys.path.insert(0, possible_topdir)
 
-from keystone.cmd import cli
-
 
 # entry point.
 def main():
-    dev_conf = os.path.join(possible_topdir,
-                            'etc',
-                            'keystone.conf')
-    config_files = None
-    if os.path.exists(dev_conf):
-        config_files = [dev_conf]
-
-    cli.main(argv=sys.argv, config_files=config_files)
+    developer_config = os.path.join(possible_topdir, 'etc', 'keystone.conf')
+    if not os.path.exists(developer_config):
+        developer_config = None
+    cli.main(argv=sys.argv, developer_config_file=developer_config)
