@@ -15,19 +15,22 @@
 import ast
 import re
 
+import flask
 import jsonschema
 from oslo_config import cfg
 from oslo_log import log
+from oslo_serialization import jsonutils
 from oslo_utils import timeutils
-import six
 
+from keystone.common import provider_api
 import keystone.conf
 from keystone import exception
-from keystone.i18n import _, _LW
+from keystone.i18n import _
 
 
 CONF = keystone.conf.CONF
 LOG = log.getLogger(__name__)
+PROVIDERS = provider_api.ProviderAPIs
 
 
 class UserType(object):
@@ -37,6 +40,21 @@ class UserType(object):
     LOCAL = 'local'
 
 
+ROLE_PROPERTIES = {
+    "type": "array",
+    "items": {
+        "type": "object",
+        "required": ["name"],
+        "properties": {
+            "name": {
+                "type": "string"
+            },
+            "additionalProperties": False
+        }
+    }
+}
+
+
 MAPPING_SCHEMA = {
     "type": "object",
     "required": ['rules'],
@@ -72,6 +90,18 @@ MAPPING_SCHEMA = {
                                     },
                                     "additionalProperties": False
                                 },
+                                "projects": {
+                                    "type": "array",
+                                    "items": {
+                                        "type": "object",
+                                        "required": ["name", "roles"],
+                                        "additionalProperties": False,
+                                        "properties": {
+                                            "name": {"type": "string"},
+                                            "roles": ROLE_PROPERTIES
+                                        }
+                                    }
+                                },
                                 "group": {
                                     "type": "object",
                                     "oneOf": [
@@ -160,6 +190,9 @@ MAPPING_SCHEMA = {
                 },
                 "blacklist": {
                     "type": "array"
+                },
+                "regex": {
+                    "type": "boolean"
                 }
             }
         },
@@ -173,6 +206,9 @@ MAPPING_SCHEMA = {
                 },
                 "whitelist": {
                     "type": "array"
+                },
+                "regex": {
+                    "type": "boolean"
                 }
             }
         },
@@ -214,6 +250,10 @@ class DirectMaps(object):
     def __init__(self):
         self._matches = []
 
+    def __str__(self):
+        """return the direct map array as a string."""
+        return '%s' % self._matches
+
     def add(self, values):
         """Add a matched value to the list of matches.
 
@@ -242,28 +282,38 @@ def validate_mapping_structure(ref):
         raise exception.ValidationError(messages)
 
 
-def validate_expiration(token_ref):
-    if timeutils.utcnow() > token_ref.expires:
+def validate_expiration(token):
+    token_expiration_datetime = timeutils.normalize_time(
+        timeutils.parse_isotime(token.expires_at)
+    )
+    if timeutils.utcnow() > token_expiration_datetime:
         raise exception.Unauthorized(_('Federation token is expired'))
 
 
-def get_remote_id_parameter(protocol):
+def get_remote_id_parameter(idp, protocol):
     # NOTE(marco-fargetta): Since we support any protocol ID, we attempt to
-    # retrieve the remote_id_attribute of the protocol ID. If it's not
-    # registered in the config, then register the option and try again.
-    # This allows the user to register protocols other than oidc and saml2.
-    remote_id_parameter = None
-    try:
-        remote_id_parameter = CONF[protocol]['remote_id_attribute']
-    except AttributeError:
-        # TODO(dolph): Move configuration registration to keystone.conf
-        CONF.register_opt(cfg.StrOpt('remote_id_attribute'),
-                          group=protocol)
+    # retrieve the remote_id_attribute of the protocol ID. It will look up
+    # first if the remote_id_attribute exists.
+    protocol_ref = PROVIDERS.federation_api.get_protocol(idp['id'], protocol)
+    remote_id_parameter = protocol_ref.get('remote_id_attribute')
+    if remote_id_parameter:
+        return remote_id_parameter
+    else:
+        # If it's not registered in the config, then register the option and
+        # try again. This allows the user to register protocols other than
+        # oidc and saml2.
         try:
             remote_id_parameter = CONF[protocol]['remote_id_attribute']
-        except AttributeError:  # nosec
-            # No remote ID attr, will be logged and use the default instead.
-            pass
+        except AttributeError:
+            # TODO(dolph): Move configuration registration to keystone.conf
+            CONF.register_opt(cfg.StrOpt('remote_id_attribute'),
+                              group=protocol)
+            try:
+                remote_id_parameter = CONF[protocol]['remote_id_attribute']
+            except AttributeError:  # nosec
+                # No remote ID attr, will be logged and use the default
+                # instead.
+                pass
     if not remote_id_parameter:
         LOG.debug('Cannot find "remote_id_attribute" in configuration '
                   'group %s. Trying default location in '
@@ -275,7 +325,7 @@ def get_remote_id_parameter(protocol):
 
 def validate_idp(idp, protocol, assertion):
     """The IdP providing the assertion should be registered for the mapping."""
-    remote_id_parameter = get_remote_id_parameter(protocol)
+    remote_id_parameter = get_remote_id_parameter(idp, protocol)
     if not remote_id_parameter or not idp['remote_ids']:
         LOG.debug('Impossible to identify the IdP %s ', idp['id'])
         # If nothing is defined, the administrator may want to
@@ -326,7 +376,8 @@ def transform_to_group_ids(group_names, mapping_id,
     """Transform groups identified by name/domain to their ids.
 
     Function accepts list of groups identified by a name and domain giving
-    a list of group ids in return.
+    a list of group ids in return. A message is logged if the group doesn't
+    exist in the backend.
 
     Example of group_names parameter::
 
@@ -357,9 +408,6 @@ def transform_to_group_ids(group_names, mapping_id,
 
     :returns: generator object with group ids
 
-    :raises keystone.exception.MappedGroupNotFound: in case asked group doesn't
-        exist in the backend.
-
     """
     def resolve_domain(domain):
         """Return domain id.
@@ -383,20 +431,20 @@ def transform_to_group_ids(group_names, mapping_id,
                 group['name'], resolve_domain(group['domain']))
             yield group_dict['id']
         except exception.GroupNotFound:
-            raise exception.MappedGroupNotFound(group_id=group['name'],
-                                                mapping_id=mapping_id)
+            LOG.debug('Group %s has no entry in the backend',
+                      group['name'])
 
 
-def get_assertion_params_from_env(request):
-    LOG.debug('Environment variables: %s', request.environ)
+def get_assertion_params_from_env():
+    LOG.debug('Environment variables: %s', flask.request.environ)
     prefix = CONF.federation.assertion_prefix
-    for k, v in list(request.environ.items()):
+    for k, v in list(flask.request.environ.items()):
         if not k.startswith(prefix):
             continue
         # These bytes may be decodable as ISO-8859-1 according to Section
         # 3.2.4 of RFC 7230. Let's assume that our web server plugins are
         # correctly encoding the data.
-        if not isinstance(v, six.text_type) and getattr(v, 'decode', False):
+        if not isinstance(v, str) and getattr(v, 'decode', False):
             v = v.decode('ISO-8859-1')
         yield (k, v)
 
@@ -485,7 +533,7 @@ class RuleProcessor(object):
         # any multiple values are stored in the arrays.
         LOG.debug('assertion data: %s', assertion_data)
         assertion = {n: v.split(';') for n, v in assertion_data.items()
-                     if isinstance(v, six.string_types)}
+                     if isinstance(v, str)}
         LOG.debug('assertion: %s', assertion)
         identity_values = []
 
@@ -514,6 +562,48 @@ class RuleProcessor(object):
         LOG.debug('mapped_properties: %s', mapped_properties)
         return mapped_properties
 
+    def _normalize_groups(self, identity_value):
+        # In this case, identity_value['groups'] is a string
+        # representation of a list, and we want a real list.  This is
+        # due to the way we do direct mapping substitutions today (see
+        # function _update_local_mapping() )
+        if 'name' in identity_value['groups']:
+            try:
+                group_names_list = ast.literal_eval(
+                    identity_value['groups'])
+            except (ValueError, SyntaxError):
+                group_names_list = [identity_value['groups']]
+
+            def convert_json(group):
+                if group.startswith('JSON:'):
+                    return jsonutils.loads(group.lstrip('JSON:'))
+                return group
+
+            group_dicts = [convert_json(g) for g in group_names_list]
+            for g in group_dicts:
+                if 'domain' not in g:
+                    msg = _("Invalid rule: %(identity_value)s. Both "
+                            "'groups' and 'domain' keywords must be "
+                            "specified.")
+                    msg = msg % {'identity_value': identity_value}
+                    raise exception.ValidationError(msg)
+        else:
+            if 'domain' not in identity_value:
+                msg = _("Invalid rule: %(identity_value)s. Both "
+                        "'groups' and 'domain' keywords must be "
+                        "specified.")
+                msg = msg % {'identity_value': identity_value}
+                raise exception.ValidationError(msg)
+            try:
+                group_names_list = ast.literal_eval(
+                    identity_value['groups'])
+            except (ValueError, SyntaxError):
+                group_names_list = [identity_value['groups']]
+            domain = identity_value['domain']
+            group_dicts = [{'name': name, 'domain': domain} for name in
+                           group_names_list]
+        return group_dicts
+
     def _transform(self, identity_values):
         """Transform local mappings, to an easier to understand format.
 
@@ -563,33 +653,32 @@ class RuleProcessor(object):
                 raise exception.ValidationError(msg)
 
             if user_type is None:
-                user_type = user['type'] = UserType.EPHEMERAL
-
-            if user_type == UserType.EPHEMERAL:
-                user['domain'] = {
-                    'id': CONF.federation.federated_domain_name
-                }
+                user['type'] = UserType.EPHEMERAL
 
         # initialize the group_ids as a set to eliminate duplicates
         user = {}
         group_ids = set()
         group_names = list()
         groups_by_domain = dict()
+        projects = []
 
         # if mapping yield no valid identity values, we should bail right away
         # instead of continuing on with a normalized bogus user
         if not identity_values:
-            msg = _("Could not map any federated user properties to identity "
-                    "values. Check debug logs or the mapping used for "
-                    "additional details.")
+            msg = ("Could not map any federated user properties to identity "
+                   "values. Check debug logs or the mapping used for "
+                   "additional details.")
+            tr_msg = _("Could not map any federated user properties to "
+                       "identity values. Check debug logs or the mapping "
+                       "used for additional details.")
             LOG.warning(msg)
-            raise exception.ValidationError(msg)
+            raise exception.ValidationError(tr_msg)
 
         for identity_value in identity_values:
             if 'user' in identity_value:
                 # if a mapping outputs more than one user name, log it
                 if user:
-                    LOG.warning(_LW('Ignoring user name'))
+                    LOG.warning('Ignoring user name')
                 else:
                     user = identity_value.get('user')
             if 'group' in identity_value:
@@ -602,24 +691,7 @@ class RuleProcessor(object):
                     groups_by_domain.setdefault(domain, list()).append(group)
                 group_names.extend(extract_groups(groups_by_domain))
             if 'groups' in identity_value:
-                if 'domain' not in identity_value:
-                    msg = _("Invalid rule: %(identity_value)s. Both 'groups' "
-                            "and 'domain' keywords must be specified.")
-                    msg = msg % {'identity_value': identity_value}
-                    raise exception.ValidationError(msg)
-                # In this case, identity_value['groups'] is a string
-                # representation of a list, and we want a real list.  This is
-                # due to the way we do direct mapping substitutions today (see
-                # function _update_local_mapping() )
-                try:
-                    group_names_list = ast.literal_eval(
-                        identity_value['groups'])
-                except ValueError:
-                    group_names_list = [identity_value['groups']]
-                domain = identity_value['domain']
-                group_dicts = [{'name': name, 'domain': domain} for name in
-                               group_names_list]
-
+                group_dicts = self._normalize_groups(identity_value)
                 group_names.extend(group_dicts)
             if 'group_ids' in identity_value:
                 # If identity_values['group_ids'] is a string representation
@@ -632,12 +704,15 @@ class RuleProcessor(object):
                         ast.literal_eval(identity_value['group_ids']))
                 except (ValueError, SyntaxError):
                     group_ids.update([identity_value['group_ids']])
+            if 'projects' in identity_value:
+                projects = identity_value['projects']
 
         normalize_user(user)
 
         return {'user': user,
                 'group_ids': list(group_ids),
-                'group_names': group_names}
+                'group_names': group_names,
+                'projects': projects}
 
     def _update_local_mapping(self, local, direct_maps):
         """Replace any {0}, {1} ... values with data from the assertion.
@@ -653,7 +728,7 @@ class RuleProcessor(object):
 
         Example direct_maps::
 
-            ['Bob', 'Thompson', 'bob@example.com']
+            [['Bob'], ['Thompson'], ['bob@example.com']]
 
         :returns: new local mapping reference with replaced values.
 
@@ -671,6 +746,9 @@ class RuleProcessor(object):
         for k, v in local.items():
             if isinstance(v, dict):
                 new_value = self._update_local_mapping(v, direct_maps)
+            elif isinstance(v, list):
+                new_value = [self._update_local_mapping(item, direct_maps)
+                             for item in v]
             else:
                 try:
                     new_value = v.format(*direct_maps)
@@ -772,11 +850,17 @@ class RuleProcessor(object):
             # If a blacklist or whitelist is used, we want to map to the
             # whole list instead of just its values separately.
             if blacklisted_values is not None:
-                direct_map_values = [v for v in direct_map_values
-                                     if v not in blacklisted_values]
+                direct_map_values = (
+                    self._evaluate_requirement(blacklisted_values,
+                                               direct_map_values,
+                                               self._EvalType.BLACKLIST,
+                                               regex))
             elif whitelisted_values is not None:
-                direct_map_values = [v for v in direct_map_values
-                                     if v in whitelisted_values]
+                direct_map_values = (
+                    self._evaluate_requirement(whitelisted_values,
+                                               direct_map_values,
+                                               self._EvalType.WHITELIST,
+                                               regex))
 
             direct_maps.add(direct_map_values)
 
@@ -785,20 +869,26 @@ class RuleProcessor(object):
         return direct_maps
 
     def _evaluate_values_by_regex(self, values, assertion_values):
-        for value in values:
-            for assertion_value in assertion_values:
-                if re.search(value, assertion_value):
-                    return True
-        return False
+        return [
+            assertion for assertion in assertion_values
+            if any([re.search(regex, assertion) for regex in values])
+        ]
 
     def _evaluate_requirement(self, values, assertion_values,
                               eval_type, regex):
         """Evaluate the incoming requirement and assertion.
 
-        If the requirement type does not exist in the assertion data, then
-        return False. If regex is specified, then compare the values and
-        assertion values. Otherwise, grab the intersection of the values
-        and use that to compare against the evaluation type.
+        Filter the incoming assertions against the requirement values. If regex
+        is specified, the assertion list is filtered by checking if any of the
+        requirement regexes matches. Otherwise, the list is filtered by string
+        equality with any of the allowed values.
+
+        Once the assertion values are filtered, the output is determined by the
+        evaluation type:
+            any_one_of: return True if there are any matches, False otherwise
+            not_any_of: return True if there are no matches, False otherwise
+            blacklist: return the incoming values minus any matches
+            whitelist: return only the matched values
 
         :param values: list of allowed values, defined in the requirement
         :type values: list
@@ -809,33 +899,46 @@ class RuleProcessor(object):
         :param regex: perform evaluation with regex
         :type regex: boolean
 
-        :returns: boolean, whether requirement is valid or not.
+        :returns: list of filtered assertion values (if evaluation type is
+                  'blacklist' or 'whitelist'), or boolean indicating if the
+                  assertion values fulfill the requirement (if evaluation type
+                  is 'any_one_of' or 'not_any_of')
 
         """
         if regex:
-            any_match = self._evaluate_values_by_regex(values,
-                                                       assertion_values)
+            matches = self._evaluate_values_by_regex(values, assertion_values)
         else:
-            any_match = bool(set(values).intersection(set(assertion_values)))
-        if any_match and eval_type == self._EvalType.ANY_ONE_OF:
-            return True
-        if not any_match and eval_type == self._EvalType.NOT_ANY_OF:
-            return True
+            matches = set(values).intersection(set(assertion_values))
 
-        return False
+        if eval_type == self._EvalType.ANY_ONE_OF:
+            return bool(matches)
+        elif eval_type == self._EvalType.NOT_ANY_OF:
+            return not bool(matches)
+        elif eval_type == self._EvalType.BLACKLIST:
+            return list(set(assertion_values).difference(set(matches)))
+        elif eval_type == self._EvalType.WHITELIST:
+            return list(matches)
+        else:
+            raise exception.UnexpectedError(
+                _('Unexpected evaluation type "%(eval_type)s"') % {
+                    'eval_type': eval_type})
 
 
 def assert_enabled_identity_provider(federation_api, idp_id):
     identity_provider = federation_api.get_idp(idp_id)
     if identity_provider.get('enabled') is not True:
-        msg = _('Identity Provider %(idp)s is disabled') % {'idp': idp_id}
+        msg = 'Identity Provider %(idp)s is disabled' % {
+            'idp': idp_id}
+        tr_msg = _('Identity Provider %(idp)s is disabled') % {
+            'idp': idp_id}
         LOG.debug(msg)
-        raise exception.Forbidden(msg)
+        raise exception.Forbidden(tr_msg)
 
 
 def assert_enabled_service_provider_object(service_provider):
     if service_provider.get('enabled') is not True:
         sp_id = service_provider['id']
-        msg = _('Service Provider %(sp)s is disabled') % {'sp': sp_id}
+        msg = 'Service Provider %(sp)s is disabled' % {'sp': sp_id}
+        tr_msg = _('Service Provider %(sp)s is disabled') % {'sp': sp_id}
         LOG.debug(msg)
-        raise exception.Forbidden(msg)
+        raise exception.Forbidden(tr_msg)
