@@ -14,8 +14,6 @@
 
 """Fixtures for Federation Mapping."""
 
-from six.moves import range, zip
-
 
 EMPLOYEE_GROUP_ID = "0cd5e9"
 CONTRACTOR_GROUP_ID = "85a868"
@@ -889,6 +887,54 @@ MAPPING_GROUPS_BLACKLIST = {
     ]
 }
 
+MAPPING_GROUPS_BLACKLIST_REGEX = {
+    "rules": [
+        {
+            "remote": [
+                {
+                    "type": "orgPersonType",
+                    "blacklist": [
+                        ".*Employee$"
+                    ],
+                    "regex": True
+                },
+            ],
+            "local": [
+                {
+                    "groups": "{0}",
+                    "domain": {
+                        "id": FEDERATED_DOMAIN
+                    }
+                },
+            ]
+        }
+    ]
+}
+
+MAPPING_GROUPS_WHITELIST_REGEX = {
+    "rules": [
+        {
+            "remote": [
+                {
+                    "type": "orgPersonType",
+                    "whitelist": [
+                        ".*Employee$"
+                    ],
+                    "regex": True
+                },
+            ],
+            "local": [
+                {
+                    "groups": "{0}",
+                    "domain": {
+                        "id": FEDERATED_DOMAIN
+                    }
+                },
+            ]
+        }
+    ]
+}
+
 # Exercise all possibilities of user identification. Values are hardcoded on
 # purpose.
 MAPPING_USER_IDS = {
@@ -1494,6 +1540,35 @@ MAPPING_GROUPS_WITH_EMAIL = {
     ]
 }
 
+
+MAPPING_GROUPS_DOMAIN_OF_USER = {
+    "rules": [
+        {
+            "local":
+            [
+                {
+                    "user":
+                        {
+                            "name": "{0}"
+                        }
+                },
+                {
+                    "groups": "{1}"
+                }
+            ],
+            "remote":
+            [
+                {
+                    "type": "openstack_user"
+                },
+                {
+                    "type": "openstack_groups"
+                }
+            ]
+        }
+    ]
+}
+
 EMPLOYEE_ASSERTION = {
     'Email': 'tim@example.com',
     'UserName': 'tbo',
@@ -1502,6 +1577,14 @@ EMPLOYEE_ASSERTION = {
     'orgPersonType': 'Employee;BuildingX'
 }
 
+EMPLOYEE_PARTTIME_ASSERTION = {
+    'Email': 'tim@example.com',
+    'UserName': 'tbo',
+    'FirstName': 'Tim',
+    'LastName': 'Bo',
+    'orgPersonType': 'Employee;PartTimeEmployee;Manager'
+}
+
 EMPLOYEE_ASSERTION_MULTIPLE_GROUPS = {
     'Email': 'tim@example.com',
     'UserName': 'tbo',
@@ -1652,6 +1735,14 @@ GROUPS_ASSERTION_ONLY_ONE_GROUP = {
     'groups': 'ALL USERS'
 }
 
+GROUPS_DOMAIN_ASSERTION = {
+    'openstack_user': 'bwilliams',
+    'openstack_user_domain': 'default',
+    'openstack_roles': 'Admin',
+    'openstack_groups': 'JSON:{"name":"group1","domain":{"name":"xxx"}};'
+                        'JSON:{"name":"group2","domain":{"name":"yyy"}}'
+}
+
 MAPPING_UNICODE = {
     "rules": [
         {
