@@ -15,17 +15,24 @@ import uuid
 import fixtures
 import flask
 import flask_restful
+import functools
 from oslo_policy import policy
 from oslo_serialization import jsonutils
 from testtools import matchers
 
+from keystone.common import context
 from keystone.common import json_home
 from keystone.common import rbac_enforcer
+import keystone.conf
 from keystone import exception
 from keystone.server.flask import common as flask_common
+from keystone.server.flask.request_processing import json_body
 from keystone.tests.unit import rest
 
 
+CONF = keystone.conf.CONF
+
+
 class _TestResourceWithCollectionInfo(flask_common.ResourceBase):
     collection_key = 'arguments'
     member_key = 'argument'
@@ -165,7 +172,7 @@ class TestKeystoneFlaskCommon(rest.RestfulTestCase):
                 },
                 'scope': {
                     'project': {
-                        'id': self.tenant_service['id']
+                        'id': self.project_service['id']
                     }
                 }
             }
@@ -397,11 +404,19 @@ class TestKeystoneFlaskCommon(rest.RestfulTestCase):
                   expected_status_code=420)
 
     def test_construct_resource_map(self):
+        resource_name = 'arguments'
         param_relation = json_home.build_v3_parameter_relation(
             'argument_id')
+        alt_rel_func = functools.partial(
+            json_home.build_v3_extension_resource_relation,
+            extension_name='extension', extension_version='1.0')
         url = '/v3/arguments/<string:argument_id>'
-        old_url = ['/v3/old_arguments/<string:argument_id>']
-        resource_name = 'arguments'
+        old_url = [dict(
+            url='/v3/old_arguments/<string:argument_id>',
+            json_home=flask_common.construct_json_home_data(
+                rel='arguments',
+                resource_relation_func=alt_rel_func)
+        )]
 
         mapping = flask_common.construct_resource_map(
             resource=_TestResourceWithCollectionInfo,
@@ -415,13 +430,17 @@ class TestKeystoneFlaskCommon(rest.RestfulTestCase):
         self.assertEqual(_TestResourceWithCollectionInfo,
                          mapping.resource)
         self.assertEqual(url, mapping.url)
-        self.assertEqual(old_url, mapping.alternate_urls)
         self.assertEqual(json_home.build_v3_resource_relation(resource_name),
                          mapping.json_home_data.rel)
         self.assertEqual(json_home.Status.EXPERIMENTAL,
                          mapping.json_home_data.status)
         self.assertEqual({'argument_id': param_relation},
                          mapping.json_home_data.path_vars)
+        # Check the alternate URL data is populated sanely
+        self.assertEqual(1, len(mapping.alternate_urls))
+        alt_url_data = mapping.alternate_urls[0]
+        self.assertEqual(old_url[0]['url'], alt_url_data['url'])
+        self.assertEqual(old_url[0]['json_home'], alt_url_data['json_home'])
 
     def test_instantiate_and_register_to_app(self):
         # Test that automatic instantiation and registration to app works.
@@ -465,6 +484,43 @@ class TestKeystoneFlaskCommon(rest.RestfulTestCase):
             resp = c.post('/v3/test_api', json=body)
             self.assertEqual(body, resp.json['post_body'])
 
+    def test_HTTP_OPTIONS_is_unenforced(self):
+        # Standup a test mapped resource and call OPTIONS on it. This will
+        # return a header "Allow" with the valid methods, in this case
+        # OPTIONS and POST. Ensure that the response otherwise conforms
+        # as expected.
+
+        class MappedResource(flask_restful.Resource):
+            def post(self):
+                # we don't actually use this or call it.
+                pass
+
+        resource_map = flask_common.construct_resource_map(
+            resource=MappedResource,
+            url='test_api',
+            alternate_urls=[],
+            resource_kwargs={},
+            rel='test',
+            status=json_home.Status.STABLE,
+            path_vars=None,
+            resource_relation_func=json_home.build_v3_resource_relation)
+
+        restful_api = _TestRestfulAPI(resource_mapping=[resource_map],
+                                      resources=[])
+        self.public_app.app.register_blueprint(restful_api.blueprint)
+        with self.test_client() as c:
+            r = c.options('/v3/test_api')
+            # make sure we split the data and left/right strip off whitespace
+            # The use of a SET here is to ensure the exact values are in place
+            # even if hash-seeds change order. `r.data` will be an empty
+            # byte-string. `Content-Length` will be 0.
+            self.assertEqual(
+                set(['OPTIONS', 'POST']),
+                set([v.lstrip().rstrip()
+                     for v in r.headers['Allow'].split(',')]))
+            self.assertEqual(r.headers['Content-Length'], '0')
+            self.assertEqual(r.data, b'')
+
     def test_mapped_resource_routes(self):
         # Test non-standard URL routes ("mapped") function as expected
 
@@ -544,3 +600,181 @@ class TestKeystoneFlaskCommon(rest.RestfulTestCase):
             for rel in json_home_data:
                 self.assertThat(resp_data['resources'][rel],
                                 matchers.Equals(json_home_data[rel]))
+
+    def test_normalize_domain_id_extracts_domain_id_if_needed(self):
+        self._setup_flask_restful_api()
+        blueprint_prefix = self.restful_api._blueprint_url_prefix.rstrip('/')
+        url = ''.join([blueprint_prefix, '/arguments'])
+        headers = {'X-Auth-Token': self._get_token()}
+        ref_with_domain_id = {'domain_id': uuid.uuid4().hex}
+        ref_without_domain_id = {}
+        with self.test_client() as c:
+            # Make a dummy request.. ANY request is fine to push the whole
+            # context stack.
+            c.get('%s/%s' % (url, uuid.uuid4().hex), headers=headers,
+                  expected_status_code=404)
+
+            oslo_context = flask.request.environ[
+                context.REQUEST_CONTEXT_ENV]
+
+            # Normal Project Scope Form
+            # ---------------------------
+            # test that _normalize_domain_id does something sane
+            domain_id = ref_with_domain_id['domain_id']
+            # Ensure we don't change the domain if it is specified
+            flask_common.ResourceBase._normalize_domain_id(ref_with_domain_id)
+            self.assertEqual(domain_id, ref_with_domain_id['domain_id'])
+            # Ensure (deprecated) we add default domain if needed
+            flask_common.ResourceBase._normalize_domain_id(
+                ref_without_domain_id)
+            self.assertEqual(
+                CONF.identity.default_domain_id,
+                ref_without_domain_id['domain_id'])
+            ref_without_domain_id.clear()
+
+            # Domain Scoped Form
+            # --------------------
+            # Just set oslo_context domain_id to a value. This is how we
+            # communicate domain scope. No need to explicitly
+            # do a domain-scoped request, this is a synthetic text anyway
+            oslo_context.domain_id = uuid.uuid4().hex
+            # Ensure we don't change the domain if it is specified
+            flask_common.ResourceBase._normalize_domain_id(ref_with_domain_id)
+            self.assertEqual(domain_id, ref_with_domain_id['domain_id'])
+            flask_common.ResourceBase._normalize_domain_id(
+                ref_without_domain_id)
+            self.assertEqual(oslo_context.domain_id,
+                             ref_without_domain_id['domain_id'])
+            ref_without_domain_id.clear()
+
+            # "Admin" Token form
+            # -------------------
+            # Explicitly set "is_admin" to true, no new request is needed
+            # as we simply check "is_admin" value everywhere
+            oslo_context.is_admin = True
+            oslo_context.domain_id = None
+            # Ensure we don't change the domain if it is specified
+            flask_common.ResourceBase._normalize_domain_id(ref_with_domain_id)
+            self.assertEqual(domain_id, ref_with_domain_id['domain_id'])
+            # Ensure we raise an appropriate exception with the inferred
+            # domain_id
+            self.assertRaises(exception.ValidationError,
+                              flask_common.ResourceBase._normalize_domain_id,
+                              ref=ref_without_domain_id)
+
+    def test_api_prefix_self_referential_link_substitution(self):
+
+        view_arg = uuid.uuid4().hex
+
+        class TestResource(flask_common.ResourceBase):
+            api_prefix = '/<string:test_value>/nothing'
+
+        # use a dummy request context, no enforcement is happening
+        # therefore we don't need the heavy lifting of a full request
+        # run.
+        with self.test_request_context(
+                path='/%s/nothing/values' % view_arg,
+                base_url='https://localhost/'):
+            # explicitly set the view_args, this is a special case
+            # for a synthetic test case, usually one would rely on
+            # a full request stack to set these.
+            flask.request.view_args = {'test_value': view_arg}
+
+            # create dummy ref
+            ref = {'id': uuid.uuid4().hex}
+
+            # add the self referential link
+            TestResource._add_self_referential_link(
+                ref, collection_name='values')
+
+            # Check that the link in fact starts with what we expect
+            # including the explicit view arg.
+            self.assertTrue(ref['links']['self'].startswith(
+                'https://localhost/v3/%s' % view_arg)
+            )
+
+    def test_json_body_before_req_func_valid_json(self):
+        with self.test_request_context(
+                headers={'Content-Type': 'application/json'},
+                data='{"key": "value"}'):
+            # No exception should be raised, everything is happy.
+            json_body.json_body_before_request()
+
+    def test_json_body_before_req_func_invalid_json(self):
+        with self.test_request_context(
+                headers={'Content-Type': 'application/json'},
+                data='invalid JSON'):
+            # keystone.exception.ValidationError should be raised
+            self.assertRaises(exception.ValidationError,
+                              json_body.json_body_before_request)
+
+    def test_json_body_before_req_func_no_content_type(self):
+        # Unset
+        with self.test_request_context(data='{"key": "value"}'):
+            # No exception should be raised, everything is happy.
+            json_body.json_body_before_request()
+
+        # Explicitly set to ''
+        with self.test_request_context(
+                headers={'Content-Type': ''}, data='{"key": "value"}'):
+            # No exception should be raised, everything is happy.
+            json_body.json_body_before_request()
+
+    def test_json_body_before_req_func_unrecognized_content_type(self):
+        with self.test_request_context(
+                headers={'Content-Type': 'unrecognized/content-type'},
+                data='{"key": "value"'):
+            # keystone.exception.ValidationError should be raised
+            self.assertRaises(exception.ValidationError,
+                              json_body.json_body_before_request)
+
+    def test_json_body_before_req_func_unrecognized_conten_type_no_body(self):
+        with self.test_request_context(
+                headers={'Content-Type': 'unrecognized/content-type'}):
+            # No exception should be raised, everything is happy.
+            json_body.json_body_before_request()
+
+    def test_resource_collection_key_raises_exception_if_unset(self):
+        class TestResource(flask_common.ResourceBase):
+            """A Test Resource."""
+
+        class TestResourceWithKey(flask_common.ResourceBase):
+            collection_key = uuid.uuid4().hex
+
+        r = TestResource()
+        self.assertRaises(ValueError, getattr, r, 'collection_key')
+
+        r = TestResourceWithKey()
+        self.assertEqual(
+            TestResourceWithKey.collection_key, r.collection_key)
+
+    def test_resource_member_key_raises_exception_if_unset(self):
+        class TestResource(flask_common.ResourceBase):
+            """A Test Resource."""
+
+        class TestResourceWithKey(flask_common.ResourceBase):
+            member_key = uuid.uuid4().hex
+
+        r = TestResource()
+        self.assertRaises(ValueError, getattr, r, 'member_key')
+
+        r = TestResourceWithKey()
+        self.assertEqual(
+            TestResourceWithKey.member_key, r.member_key)
+
+
+class TestKeystoneFlaskUnrouted404(rest.RestfulTestCase):
+    def setUp(self):
+        super(TestKeystoneFlaskUnrouted404, self).setUp()
+        # unregister the 404 handler we explicitly set in loadapp. This
+        # makes the 404 error fallback to a standard werkzeug handling.
+        self.public_app.app.error_handler_spec[None].pop(404)
+
+    def test_unrouted_path_is_not_jsonified_404(self):
+        with self.test_client() as c:
+            path = '/{unrouted_path}'.format(unrouted_path=uuid.uuid4())
+            resp = c.get(path, expected_status_code=404)
+            # Make sure we're emitting a html error
+            self.assertIn('text/html', resp.headers['Content-Type'])
+            # Ensure the more generic flask/werkzeug 404 response is emitted
+            self.assertTrue(b'404 Not Found' in resp.data)
