@@ -15,11 +15,12 @@
 import copy
 import uuid
 
-from six.moves import http_client
+import http.client
 from testtools import matchers
 
 from keystone.common import provider_api
 from keystone.tests import unit
+from keystone.tests.unit import default_fixtures
 from keystone.tests.unit.ksfixtures import database
 from keystone.tests.unit import test_v3
 
@@ -38,7 +39,7 @@ class CatalogTestCase(test_v3.RestfulTestCase):
         r = self.put(
             '/regions/%s' % region_id,
             body={'region': ref},
-            expected_status=http_client.CREATED)
+            expected_status=http.client.CREATED)
         self.assertValidRegionResponse(r, ref)
         # Double-check that the region ID was kept as-is and not
         # populated with a UUID, as is the case with POST /v3/regions
@@ -51,7 +52,7 @@ class CatalogTestCase(test_v3.RestfulTestCase):
         r = self.put(
             '/regions/%s' % region_id,
             body={'region': ref},
-            expected_status=http_client.CREATED)
+            expected_status=http.client.CREATED)
         self.assertValidRegionResponse(r, ref)
         # Double-check that the region ID was kept as-is and not
         # populated with a UUID, as is the case with POST /v3/regions
@@ -63,11 +64,11 @@ class CatalogTestCase(test_v3.RestfulTestCase):
         region_id = ref['id']
         self.put(
             '/regions/%s' % region_id,
-            body={'region': ref}, expected_status=http_client.CREATED)
+            body={'region': ref}, expected_status=http.client.CREATED)
         # Create region again with duplicate id
         self.put(
             '/regions/%s' % region_id,
-            body={'region': ref}, expected_status=http_client.CONFLICT)
+            body={'region': ref}, expected_status=http.client.CONFLICT)
 
     def test_create_region(self):
         """Call ``POST /regions`` with an ID in the request body."""
@@ -162,14 +163,14 @@ class CatalogTestCase(test_v3.RestfulTestCase):
         self.put(
             '/regions/%s' % uuid.uuid4().hex,
             body={'region': ref},
-            expected_status=http_client.BAD_REQUEST)
+            expected_status=http.client.BAD_REQUEST)
 
     def test_list_head_regions(self):
         """Call ``GET & HEAD /regions``."""
         resource_url = '/regions'
         r = self.get(resource_url)
         self.assertValidRegionListResponse(r, ref=self.region)
-        self.head(resource_url, expected_status=http_client.OK)
+        self.head(resource_url, expected_status=http.client.OK)
 
     def _create_region_with_parent_id(self, parent_id=None):
         ref = unit.new_region_ref(parent_region_id=parent_id)
@@ -196,7 +197,7 @@ class CatalogTestCase(test_v3.RestfulTestCase):
             'region_id': self.region_id}
         r = self.get(resource_url)
         self.assertValidRegionResponse(r, self.region)
-        self.head(resource_url, expected_status=http_client.OK)
+        self.head(resource_url, expected_status=http.client.OK)
 
     def test_update_region(self):
         """Call ``PATCH /regions/{region_id}``."""
@@ -301,26 +302,26 @@ class CatalogTestCase(test_v3.RestfulTestCase):
         """Call ``POST /services``."""
         ref = unit.new_service_ref(enabled='True')
         self.post('/services', body={'service': ref},
-                  expected_status=http_client.BAD_REQUEST)
+                  expected_status=http.client.BAD_REQUEST)
 
     def test_create_service_enabled_str_false(self):
         """Call ``POST /services``."""
         ref = unit.new_service_ref(enabled='False')
         self.post('/services', body={'service': ref},
-                  expected_status=http_client.BAD_REQUEST)
+                  expected_status=http.client.BAD_REQUEST)
 
     def test_create_service_enabled_str_random(self):
         """Call ``POST /services``."""
         ref = unit.new_service_ref(enabled='puppies')
         self.post('/services', body={'service': ref},
-                  expected_status=http_client.BAD_REQUEST)
+                  expected_status=http.client.BAD_REQUEST)
 
     def test_list_head_services(self):
         """Call ``GET & HEAD /services``."""
         resource_url = '/services'
         r = self.get(resource_url)
         self.assertValidServiceListResponse(r, ref=self.service)
-        self.head(resource_url, expected_status=http_client.OK)
+        self.head(resource_url, expected_status=http.client.OK)
 
     def _create_random_service(self):
         ref = unit.new_service_ref()
@@ -376,7 +377,7 @@ class CatalogTestCase(test_v3.RestfulTestCase):
             'service_id': self.service_id}
         r = self.get(resource_url)
         self.assertValidServiceResponse(r, self.service)
-        self.head(resource_url, expected_status=http_client.OK)
+        self.head(resource_url, expected_status=http.client.OK)
 
     def test_update_service(self):
         """Call ``PATCH /services/{service_id}``."""
@@ -399,7 +400,7 @@ class CatalogTestCase(test_v3.RestfulTestCase):
         resource_url = '/endpoints'
         r = self.get(resource_url)
         self.assertValidEndpointListResponse(r, ref=self.endpoint)
-        self.head(resource_url, expected_status=http_client.OK)
+        self.head(resource_url, expected_status=http.client.OK)
 
     def _create_random_endpoint(self, interface='public',
                                 parent_region_id=None):
@@ -562,7 +563,7 @@ class CatalogTestCase(test_v3.RestfulTestCase):
                                     region_id=self.region_id,
                                     enabled='True')
         self.post('/endpoints', body={'endpoint': ref},
-                  expected_status=http_client.BAD_REQUEST)
+                  expected_status=http.client.BAD_REQUEST)
 
     def test_create_endpoint_enabled_str_false(self):
         """Call ``POST /endpoints`` with enabled: 'False'."""
@@ -571,7 +572,7 @@ class CatalogTestCase(test_v3.RestfulTestCase):
                                     region_id=self.region_id,
                                     enabled='False')
         self.post('/endpoints', body={'endpoint': ref},
-                  expected_status=http_client.BAD_REQUEST)
+                  expected_status=http.client.BAD_REQUEST)
 
     def test_create_endpoint_enabled_str_random(self):
         """Call ``POST /endpoints`` with enabled: 'puppies'."""
@@ -580,13 +581,13 @@ class CatalogTestCase(test_v3.RestfulTestCase):
                                     region_id=self.region_id,
                                     enabled='puppies')
         self.post('/endpoints', body={'endpoint': ref},
-                  expected_status=http_client.BAD_REQUEST)
+                  expected_status=http.client.BAD_REQUEST)
 
     def test_create_endpoint_with_invalid_region_id(self):
         """Call ``POST /endpoints``."""
         ref = unit.new_endpoint_ref(service_id=self.service_id)
         self.post('/endpoints', body={'endpoint': ref},
-                  expected_status=http_client.BAD_REQUEST)
+                  expected_status=http.client.BAD_REQUEST)
 
     def test_create_endpoint_with_region(self):
         """EndpointV3 creates the region before creating the endpoint.
@@ -609,7 +610,7 @@ class CatalogTestCase(test_v3.RestfulTestCase):
         """Call ``POST /endpoints``."""
         ref = unit.new_endpoint_ref(service_id=self.service_id, url='')
         self.post('/endpoints', body={'endpoint': ref},
-                  expected_status=http_client.BAD_REQUEST)
+                  expected_status=http.client.BAD_REQUEST)
 
     def test_get_head_endpoint(self):
         """Call ``GET & HEAD /endpoints/{endpoint_id}``."""
@@ -617,7 +618,7 @@ class CatalogTestCase(test_v3.RestfulTestCase):
             'endpoint_id': self.endpoint_id}
         r = self.get(resource_url)
         self.assertValidEndpointResponse(r, self.endpoint)
-        self.head(resource_url, expected_status=http_client.OK)
+        self.head(resource_url, expected_status=http.client.OK)
 
     def test_update_endpoint(self):
         """Call ``PATCH /endpoints/{endpoint_id}``."""
@@ -656,7 +657,7 @@ class CatalogTestCase(test_v3.RestfulTestCase):
             '/endpoints/%(endpoint_id)s' % {
                 'endpoint_id': self.endpoint_id},
             body={'endpoint': {'enabled': 'True'}},
-            expected_status=http_client.BAD_REQUEST)
+            expected_status=http.client.BAD_REQUEST)
 
     def test_update_endpoint_enabled_str_false(self):
         """Call ``PATCH /endpoints/{endpoint_id}`` with enabled: 'False'."""
@@ -664,7 +665,7 @@ class CatalogTestCase(test_v3.RestfulTestCase):
             '/endpoints/%(endpoint_id)s' % {
                 'endpoint_id': self.endpoint_id},
             body={'endpoint': {'enabled': 'False'}},
-            expected_status=http_client.BAD_REQUEST)
+            expected_status=http.client.BAD_REQUEST)
 
     def test_update_endpoint_enabled_str_random(self):
         """Call ``PATCH /endpoints/{endpoint_id}`` with enabled: 'kitties'."""
@@ -672,7 +673,7 @@ class CatalogTestCase(test_v3.RestfulTestCase):
             '/endpoints/%(endpoint_id)s' % {
                 'endpoint_id': self.endpoint_id},
             body={'endpoint': {'enabled': 'kitties'}},
-            expected_status=http_client.BAD_REQUEST)
+            expected_status=http.client.BAD_REQUEST)
 
     def test_delete_endpoint(self):
         """Call ``DELETE /endpoints/{endpoint_id}``."""
@@ -682,7 +683,7 @@ class CatalogTestCase(test_v3.RestfulTestCase):
 
     def test_deleting_endpoint_with_space_in_url(self):
         # add a space to all urls (intentional "i d" to test bug)
-        url_with_space = "http://127.0.0.1:8774 /v1.1/\$(tenant_i d)s"
+        url_with_space = "http://127.0.0.1:8774 /v1.1/\\$(tenant_i d)s"
 
         # create a v3 endpoint ref
         ref = unit.new_endpoint_ref(service_id=self.service['id'],
@@ -700,7 +701,7 @@ class CatalogTestCase(test_v3.RestfulTestCase):
 
         # make sure it's deleted (GET should return Not Found)
         self.get('/endpoints/%s' % ref['id'],
-                 expected_status=http_client.NOT_FOUND)
+                 expected_status=http.client.NOT_FOUND)
 
     def test_endpoint_create_with_valid_url(self):
         """Create endpoint with valid url should be tested,too."""
@@ -745,7 +746,7 @@ class CatalogTestCase(test_v3.RestfulTestCase):
             ref['url'] = invalid_url
             self.post('/endpoints',
                       body={'endpoint': ref},
-                      expected_status=http_client.BAD_REQUEST)
+                      expected_status=http.client.BAD_REQUEST)
 
 
 class TestMultiRegion(test_v3.RestfulTestCase):
@@ -832,6 +833,9 @@ class TestCatalogAPISQL(unit.TestCase):
 
         self.create_endpoint(service_id=self.service_id)
 
+        PROVIDERS.resource_api.create_domain(
+            default_fixtures.ROOT_DOMAIN['id'], default_fixtures.ROOT_DOMAIN)
+
     def create_endpoint(self, service_id, **kwargs):
         endpoint = unit.new_endpoint_ref(service_id=service_id,
                                          region_id=None, **kwargs)
@@ -929,6 +933,8 @@ class TestCatalogAPISQLRegions(unit.TestCase):
         super(TestCatalogAPISQLRegions, self).setUp()
         self.useFixture(database.Database())
         self.load_backends()
+        PROVIDERS.resource_api.create_domain(
+            default_fixtures.ROOT_DOMAIN['id'], default_fixtures.ROOT_DOMAIN)
 
     def config_overrides(self):
         super(TestCatalogAPISQLRegions, self).config_overrides()
@@ -998,7 +1004,7 @@ class TestCatalogAPITemplatedProject(test_v3.RestfulTestCase):
         super(TestCatalogAPITemplatedProject, self).config_overrides()
         self.config_fixture.config(group='catalog', driver='templated')
 
-    def load_fixtures(self, fixtures, enable_sqlite_foreign_key=False):
+    def load_fixtures(self, fixtures):
         self.load_sample_data(create_region_and_endpoints=False)
 
     def test_project_delete(self):
